#ifndef HISTORYINFOWINDOW_H
#define HISTORYINFOWINDOW_H

#include <QMainWindow>
#include <QtGui>
#include "xml.h"

class HistoryInfoWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit HistoryInfoWindow(QWidget *parent = 0);
    void load(QString name, QString group);

private:
    XML *xml;

    QLabel *lblSet[9];

};

#endif //HISTORYINFOWINDOW_H
